@@ -19,21 +19,37 @@
 #define SETTINGSCONTROLLER_H
 
 #include <QString>
+#include <QObject>
 
+class MainWindow;
 class Settings;
 
-class SettingsController
+class SettingsController : public QObject
 {
+    Q_OBJECT
 public:
-    SettingsController(Settings *settings);
+    SettingsController(MainWindow *main_window, Settings *settings);
 
     void Load();
     void Save();
 
+    void EmitInitialSettings();
+
+public:
+    Q_SIGNAL void SettingsChanged(const Settings &);
+
+public:
+    Q_SLOT void OpenSettingsDialog();
+
+private:
+    Q_SLOT void AcceptSettingsDialog(const Settings &);
+    Q_SLOT void CancelSettingsDialog(const Settings &);
+
 private:
     QString GetSettingsFileName();
 
 private:
+    MainWindow *_main_window;
     Settings *_settings;
 };
 
